===============================
cellpy
===============================


.. image:: https://img.shields.io/pypi/v/cellpy.svg
        :target: https://pypi.python.org/pypi/cellpy

.. image:: https://img.shields.io/travis/jepegit/cellpy.svg
        :target: https://travis-ci.org/jepegit/cellpy

.. image:: https://readthedocs.org/projects/cellpy/badge/?version=latest
        :target: https://cellpy.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status


This Python Package was developed to help the
researchers at IFE, Norway, in their cumbersome task of
interpreting and handling data from cycling tests of
batteries and cells.

Documentation
-------------

The documentation for ``cellpy`` is hosted on `Read the docs
<https://cellpy.readthedocs.io>`_.


Installation and dependencies
-----------------------------

The easiest way to install ``cellpy`` is to install with conda or pip::

   conda install cellpy --channel conda-forge

If you prefer, you can also install using pip::

   pip install cellpy

Have a look at the documentation for more detailed installation procedures, especially
with respect to "difficult" dependencies when installing with pip.

Licence
-------

``cellpy`` is free software made available under the MIT License.

Features
--------

* Load test-data and store in hdf5 format.
* Filter out the steps of interest.
* Process and plot the data.
* And more...


